@@ -1,10 +1,14 @@
-from BaseGoogleAPI import BaseGoogleAPI
+from .BaseGoogleAPI import BaseGoogleAPI
 import googleapiclient.discovery
 
 class GCPAPI(BaseGoogleAPI):
-    def __init__(self, credentials_file):
+    required_info = [
+            ('credentials_file', 'str')
+            ]
+   
+    def connect(self, credentials_file):
         self.scopes = ['https://www.googleapis.com/auth/cloud-platform']
-        super().__init__(credentials_file)
+        super().connect(credentials_file)
 
     def list_project_assets(self, project):
         security_center = googleapiclient\
@@ -20,3 +24,14 @@ class GCPAPI(BaseGoogleAPI):
             .list,
             args, 'listAssetsResults')
         return data
+
+    def methods(self):
+        m = [
+            {
+                'method_name': 'list_project_assets',
+                'method': self.list_project_assets,
+                'format': 'json'
+            }
+        ]
+        return m
+
