@@ -1,14 +1,19 @@
-from BaseGoogleAPI import BaseGoogleAPI
+from .BaseGoogleAPI import BaseGoogleAPI
 from google.oauth2 import service_account
 import googleapiclient.discovery
 
 
 class GoogleWorkspaceAPI(BaseGoogleAPI):
-    def __init__(self, credentials_file, domain, subject):
+    required_info = [
+            ('credentials_file', 'str'),
+            ('domain', 'str'),
+            ('subject', 'str')
+            ]
+    def connect(self, credentials_file, domain, subject):
         self.scopes = [
                 'https://www.googleapis.com/auth/admin.directory.user.readonly',
                  ]
-        super().__init__(credentials_file, subject)
+        super().connect(credentials_file, subject)
         self.domain = domain
        
 
@@ -23,3 +28,14 @@ class GoogleWorkspaceAPI(BaseGoogleAPI):
         data_ws = self.call_api(admin.users().list,
                                 args, "users")
         return data_ws
+    
+    def methods(self):
+        m = [ 
+            { 
+                'method_name':'list_users',
+                'method': self.list_users,
+                'format': 'json'
+            }
+        ]
+        return m
+
