@@ -25,43 +25,48 @@ class GraphAPI(BaseMicrosoftAPI):
         response = self.call_api(url)
         return response
 
-    def get_details(self, paramsExtract, paramsData):
-        supported_paramsExtract = [
-            'getOneDriveUsageAccountDetail',
-            'getOneDriveActivityUserDetail',
-            'getTeamsDeviceUsageUserDetail',
-            'getTeamsUserActivityUserDetail',
-            'getEmailActivityUserDetail',
-            'getEmailAppUsageUserDetail',
-            'getSharePointActivityUserDetail',
-            'getSharePointSiteUsageDetail',
-            'getSkypeForBusinessActivityUserDetail',
-            'getSkypeForBusinessDeviceUsageUserDetail',
-            'getYammerActivityUserDetail',
-            'getYammerDeviceUsageUserDetail',
-            'getOffice365ActiveUserDetail'
-        ]
+    def get_details(self, listParamsExtract, paramsData):
+        results = []
+        for item in listParamsExtract:
 
-        if paramsData[0] == 'period':
-            supported_paramsExtract+=['getSkypeForBusinessOrganizerActivityUserCounts',\
-                'getMailboxUsageDetail','getMailboxUsageStorage']
+            supported_paramsExtract = [
+                'getOneDriveUsageAccountDetail',
+                'getOneDriveActivityUserDetail',
+                'getTeamsDeviceUsageUserDetail',
+                'getTeamsUserActivityUserDetail',
+                'getEmailActivityUserDetail',
+                'getEmailAppUsageUserDetail',
+                'getSharePointActivityUserDetail',
+                'getSharePointSiteUsageDetail',
+                'getSkypeForBusinessActivityUserDetail',
+                'getSkypeForBusinessDeviceUsageUserDetail',
+                'getYammerActivityUserDetail',
+                'getYammerDeviceUsageUserDetail',
+                'getOffice365ActiveUserDetail'
+            ]
 
-        if paramsExtract not in supported_paramsExtract:
-            print(f'Parameter not supported {paramsExtract} \n'\
-                  f'Supported parameters: {supported_paramsExtract}')
-            return None
+            if paramsData[0] == 'period':
+                supported_paramsExtract+=['getSkypeForBusinessOrganizerActivityUserCounts',\
+                    'getMailboxUsageDetail','getMailboxUsageStorage']
 
-        else:
-            urls = {
-            'period': f"https://graph.microsoft.com/v1.0/reports/"\
-                        f"{paramsExtract}(period='D{paramsData[1]}')",
-            'date': f"https://graph.microsoft.com/v1.0/reports/"\
-                    f"{paramsExtract}(date={paramsData[1]})"
-            }
+            if item not in supported_paramsExtract:
+                print(f'Parameter not supported {item} \n'\
+                    f'Supported parameters: {supported_paramsExtract}')
+                return None
 
-            url = urls.get(paramsData[0])
-            response = self.call_api_stream(url)
-            return response
+            else:
+                urls = {
+                'period': f"https://graph.microsoft.com/v1.0/reports/"\
+                            f"{item}(period='D{paramsData[1]}')",
+                'date': f"https://graph.microsoft.com/v1.0/reports/"\
+                        f"{item}(date={paramsData[1]})"
+                }
+
+                url = urls.get(paramsData[0])
+                response = self.call_api_stream(url)
+                results.append(response)
+
+        return results
 
     def office365_active_user_detail(self, params=('period', '7')):
         urls = {
@@ -118,7 +123,7 @@ class GraphAPI(BaseMicrosoftAPI):
             {
                 'method_name': 'get_details',
                 'method': self.get_details,
-                'format': 'csv'
+                'format': 'list_csv'
             },
         ]
         return methods
